==> haskell-warp-tls-3.2.2-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.2
id: warp-tls-3.2.2-2rkoWpinx8N14PDhdpx1gh
key: warp-tls-3.2.2-2rkoWpinx8N14PDhdpx1gh
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    Support for SSL is now obsoleted.
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
abi: 67b1f7a8e4e4239695dccdc5ace344fc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/warp-tls-3.2.2
hs-libraries: HSwarp-tls-3.2.2-2rkoWpinx8N14PDhdpx1gh
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    cryptonite-0.20-5Mid6BVFFeIFMzbvEgM6vI
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    streaming-commons-0.1.15.5-BrGdcR3e3XNFGqaZ4AHAQb
    tls-1.3.8-9T6wRIqt8iyJ3nZxhTxwgv wai-3.2.1.1-3kBgN7EuSbyJsj8pT2dpLl
    warp-3.2.8-EgA7b6HaRlKKG14lB3F9ND
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.2-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.2
id: warp-tls-3.2.2-Fq6ztsSPX0vHox79EJpxMq
key: warp-tls-3.2.2-Fq6ztsSPX0vHox79EJpxMq
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    Support for SSL is now obsoleted.
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.WarpTLS
abi: 0dd3336cb584234e5c3cccc3044d133f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/warp-tls-3.2.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/warp-tls-3.2.2
hs-libraries: HSwarp-tls-3.2.2-Fq6ztsSPX0vHox79EJpxMq
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    cryptonite-0.20-5Mid6BVFFeIFMzbvEgM6vI
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    streaming-commons-0.1.16-LHbbqfY1b1QGujRQPPkzGE
    tls-1.3.8-9T6wRIqt8iyJ3nZxhTxwgv wai-3.2.1.1-3kBgN7EuSbyJsj8pT2dpLl
    warp-3.2.8-A8TqHSTgwcWCwz7oKZzEMn
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
